parse_blob_url

Function parse_blob_url 

pub fn parse_blob_url(
    url: &ServoUrl,
) -> Result<(Uuid, ImmutableOrigin), &'static str>
Parse URL as Blob URL scheme’s definition

https://w3c.github.io/FileAPI/#url-intro

FIXME: This function should never be used to obtain the origin of a blob url, because it doesn’t consider blob URL entries.