pub struct TokenSerializationGuard {
token: Arc<BlobToken>,
}Expand description
Guarantees that blob entries kept alive the contained token are not deallocated even if this token is serialized, dropped, and then later deserialized (possibly in a different thread).
Fields
token: Arc<BlobToken>Trait Implementations
Sourceimpl Clone for TokenSerializationGuard
impl Clone for TokenSerializationGuard
Sourcefn clone(&self) -> TokenSerializationGuard
fn clone(&self) -> TokenSerializationGuard
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TokenSerializationGuard
impl Debug for TokenSerializationGuard
Sourceimpl<'a> Deserialize<'a> for TokenSerializationGuard
impl<'a> Deserialize<'a> for TokenSerializationGuard
Sourcefn deserialize<D>(de: D) -> Result<Self, <D as Deserializer<'a>>::Error>where
D: Deserializer<'a>,
fn deserialize<D>(de: D) -> Result<Self, <D as Deserializer<'a>>::Error>where
D: Deserializer<'a>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl MallocSizeOf for TokenSerializationGuard
impl MallocSizeOf for TokenSerializationGuard
Sourcefn size_of(&self, ops: &mut MallocSizeOfOps) -> usize
fn size_of(&self, ops: &mut MallocSizeOfOps) -> usize
Measure the heap usage of all descendant heap-allocated structures, but
not the space taken up by the value itself.