pub struct UrlWithBlobClaim {
url: ServoUrl,
token: Option<TokenSerializationGuard>,
}Expand description
This type upholds the variant that if the URL is a valid blob URL, then it has
a token. Violating this invariant causes logic errors, but no unsafety.
Fields
url: ServoUrltoken: Option<TokenSerializationGuard>Implementations
Sourceimpl UrlWithBlobClaim
impl UrlWithBlobClaim
pub fn new(url: ServoUrl, token: Option<TokenSerializationGuard>) -> Self
pub fn token(&self) -> Option<&BlobToken>
pub fn blob_id(&self) -> Option<Uuid>
pub fn origin(&self) -> ImmutableOrigin
Sourcepub fn for_url(url: ServoUrl) -> Result<Self, ServoUrl>
pub fn for_url(url: ServoUrl) -> Result<Self, ServoUrl>
Constructs a UrlWithBlobClaim for URLs that are not blob URLs
(Such URLs don’t need to claim anything).
Returns an Err containing the original URL if it’s a blob URL,
so it can be reused without cloning.
Sourcepub fn from_url_without_having_claimed_blob(url: ServoUrl) -> Self
pub fn from_url_without_having_claimed_blob(url: ServoUrl) -> Self
This method should only exist temporarily, and all callers should either
claim the blob or guarantee that the URL is not a blob URL.
pub fn url(&self) -> ServoUrl
Methods from Deref<Target = ServoUrl>
pub fn get_arc(&self) -> Arc<Url>
pub fn as_url(&self) -> &Url
pub fn cannot_be_a_base(&self) -> bool
pub fn domain(&self) -> Option<&str>
pub fn fragment(&self) -> Option<&str>
pub fn path(&self) -> &str
pub fn origin(&self) -> ImmutableOrigin
pub fn scheme(&self) -> &str
pub fn is_secure_scheme(&self) -> bool
Sourcepub fn is_local_scheme(&self) -> bool
pub fn is_local_scheme(&self) -> bool
Sourcepub fn is_special_scheme(&self) -> bool
pub fn is_special_scheme(&self) -> bool
Sourcepub fn is_equal_excluding_fragments(&self, other: &ServoUrl) -> bool
pub fn is_equal_excluding_fragments(&self, other: &ServoUrl) -> bool
https://url.spec.whatwg.org/#url-equivalence In the future this may be removed if the helper is added upstream in rust-url see https://github.com/servo/rust-url/issues/1063 for details
pub fn as_str(&self) -> &str
pub fn as_mut_url(&mut self) -> &mut Url
pub fn set_username(&mut self, user: &str) -> Result<(), UrlError>
pub fn set_ip_host(&mut self, addr: IpAddr) -> Result<(), UrlError>
pub fn set_password(&mut self, pass: Option<&str>) -> Result<(), UrlError>
pub fn set_fragment(&mut self, fragment: Option<&str>)
pub fn username(&self) -> &str
pub fn password(&self) -> Option<&str>
pub fn to_file_path(&self) -> Result<PathBuf, UrlError>
pub fn host(&self) -> Option<Host<&str>>
pub fn host_str(&self) -> Option<&str>
pub fn port(&self) -> Option<u16>
pub fn port_or_known_default(&self) -> Option<u16>
pub fn join(&self, input: &str) -> Result<ServoUrl, ParseError>
pub fn path_segments(&self) -> Option<Split<'_, char>>
pub fn query(&self) -> Option<&str>
Sourcepub fn debug_compact(&self) -> impl Display
pub fn debug_compact(&self) -> impl Display
Return a non-standard shortened form of the URL. Mainly intended to be used for debug printing in a constrained space (e.g., thread names).
Sourcepub fn is_potentially_trustworthy(&self) -> bool
pub fn is_potentially_trustworthy(&self) -> bool